@@ -69,6 +69,17 @@ def handle_call_schedulemanager():
         client.functions.call(external_id="cognitedata/air-functions/schedulemanager:latest", wait=False)
 
 
+def handle_check_deployment():
+    function_name, project_name = sys.argv[2].split("@")
+    client = cdf.experimental_client(project_name)
+    cdf_model_version = client.assets.retrieve(external_id=function_name).metadata["modelVersion"]
+    configuration = get_master_config()[1][project_name]
+    key1 = [i for i in configuration.keys() if i.parts[-1] == function_name][0]
+    model_version = configuration[key1].model_version
+    model_version = ".".join(model_version.split(".")[:-1])
+    return str(model_version != cdf_model_version)
+
+
 if __name__ == "__main__":
 
     if sys.argv[1] == "model":
@@ -81,3 +92,5 @@ if __name__ == "__main__":
         handle_deploy_infrastructure_schedules()
     elif sys.argv[1] == "call_schedulemanager":
         handle_call_schedulemanager()
+    elif sys.argv[1] == "check_deployment":
+        handle_check_deployment()
